# Frequenz Electricity Trading API Client Release Notes

## Summary

<!-- Here goes a general summary of what this release is about -->

## Upgrading

* Update base client from version `0.6.1` to `0.7.0` and upgrade the `Client` constructor accordingly.

## New Features

* Add str function for `DeliveryPeriod` object
* Add integration tests for the API
* Add an equality function to the Order type

## Bug Fixes

<!-- Here goes notable bug fixes that are worth a special mention or explanation -->
